# go-stats python tool

Generate statistics for a GO release based on a GOLr instance

## Install
> pip install -r requirements.txt

## Command line
> python go-stats.py -g <golr_url> -o <output_file>

Note: current GOLr instance is [http://golr-aux.geneontology.io/solr/](http://golr-aux.geneontology.io/solr/)